/*
 *  Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 *  not use this file except in compliance with the License. You may obtain a
 *  copy of the License at
 * 
 *  http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 *  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 *  License for the specific language governing permissions and limitations under
 *  the License.
 */
package nl.cloudfarming.client.field.type;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Geometry;
import java.awt.*;
import javax.swing.JPanel;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.geoviewer.jxmap.render.GeometryRenderer;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class FieldVisualPanel extends JPanel {

    private final Field field;

    public FieldVisualPanel(Field field) {
        assert field != null : "FieldVisualPanel cannot be created for null field";
        this.field = field;
    }

    @Override
    public void paint(Graphics g) {
        super.paint(g);

        //
        // draw the geometry
        //
        Graphics2D gd = (Graphics2D) g.create();
        Geometry geometry = field.getGeometry();
        Polygon polygon = new Polygon();
        if (geometry.getCoordinates().length > 1) {
            Rectangle rect = getVisibleRect();
            //returns a
            // <code>Polygon</code> whose points are (minx, miny), (maxx, miny), (maxx,
            // maxy), (minx, maxy), (minx, miny).
            Geometry boundingBox = geometry.getEnvelope();

            for (Coordinate coordinate : geometry.getCoordinates()) {

                Point point = GeometryRenderer.geoToPixel(rect, boundingBox, coordinate);
                polygon.addPoint(point.x, point.y);
            }
            gd.clip(polygon);
            // fallback to old painting if the background painter is null
            gd.fill(polygon);
            gd.dispose();
        }
    }
}
